@@ -1,8 +1,6 @@
 import json
 import os
-import platform
 import re
-import signal
 import subprocess
 
 import boto3
@@ -17,8 +15,11 @@ from lambda_forge.builders.layer_builder import LayerBuilder
 from lambda_forge.builders.project_builder import ProjectBuilder
 from lambda_forge.builders.service_builder import ServiceBuilder
 from lambda_forge.diagram import create_diagram
-from lambda_forge.live import log_cli, server_cli, trigger_cli
+from lambda_forge.live import server_cli
+from lambda_forge.logs.tail_logs import watch_logs_for_functions
 from lambda_forge.printer import Printer
+from lambda_forge.logs.launch_tui import launch_forge_logs_tui
+
 
 printer = Printer()
 
@@ -184,7 +185,9 @@ def create_project(
 
     project_builder = ProjectBuilder.a_project(name, no_docs, minimal)
 
-    project_builder = project_builder.with_cdk(repo_owner, repo_name, account, region, bucket).build()
+    project_builder = project_builder.with_cdk(
+        repo_owner, repo_name, account, region, bucket
+    ).build()
 
     if no_docs is False:
         DocsBuilder.a_doc().with_config().with_lambda_stack().build()
@@ -193,11 +196,15 @@ def create_project(
 @forge.command()
 @click.argument("name")
 @click.option("--description", required=True, help="Description for the endpoint")
-@click.option("--method", required=False, help="HTTP method for the endpoint", default="GET")
+@click.option(
+    "--method", required=False, help="HTTP method for the endpoint", default="GET"
+)
 @click.option("--belongs-to", help="Folder name you want to share code accross lambdas")
 @click.option("--endpoint", help="Endpoint for the API Gateway")
 @click.option("--no-api", help="Do not create an API Gateway endpoint", is_flag=True)
-@click.option("--websocket", help="Function is going to be used for websockets", is_flag=True)
+@click.option(
+    "--websocket", help="Function is going to be used for websockets", is_flag=True
+)
 @click.option(
     "--no-tests",
     help="Do not create unit tests and integration tests files",
@@ -210,7 +217,9 @@ def create_project(
     is_flag=True,
     default=False,
 )
-def function(name, description, method, belongs_to, endpoint, no_api, websocket, no_tests, public):
+def function(
+    name, description, method, belongs_to, endpoint, no_api, websocket, no_tests, public
+):
     """
     Creates a Lambda function with a predefined structure and API Gateway integration.
 
@@ -245,7 +254,9 @@ def create_function(
     public=False,
 ):
 
-    function_builder = FunctionBuilder.a_function(name, description).with_config(belongs)
+    function_builder = FunctionBuilder.a_function(name, description).with_config(
+        belongs
+    )
 
     if no_api is True:
         function_builder = function_builder.with_main()
@@ -260,7 +271,11 @@ def create_function(
     else:
         endpoint = endpoint or belongs or name
         if no_tests is True:
-            function_builder = function_builder.with_endpoint(endpoint).with_api(http_method, public).with_main()
+            function_builder = (
+                function_builder.with_endpoint(endpoint)
+                .with_api(http_method, public)
+                .with_main()
+            )
         else:
             function_builder = (
                 function_builder.with_endpoint(endpoint)
@@ -436,11 +451,9 @@ AVAILABLE_TYPES = ["server", "logs", "trigger"]
 
 
 @forge.command()
-@click.argument("types", type=click.Choice(AVAILABLE_TYPES))
-@click.option("-l", "--log-file", help="Name of Log file", default="live.log")
-@click.option("-i", "--include", help="Include files to watch", default=None)
-@click.option("-e", "--exclude", help="Exclude files to watch", default=None)
-def live(types, log_file, include, exclude):
+@click.option("-i", "--include", help="Include functions to watch", default=None)
+@click.option("-e", "--exclude", help="Exclude functions to watch", default=None)
+def live(include, exclude):
     """
     Starts a live development environment for the specified Lambda function.
 
@@ -450,34 +463,31 @@ def live(types, log_file, include, exclude):
     The 'function_name' parameter must match the name of an existing Lambda function in the project.
     """
 
-    def handle_exit(signum, frame):
-        try:
-            if platform.system() == "Windows":
-                subprocess.run(["taskkill", "/F", "/IM", "live_server.py"], check=True)
-            else:
-                subprocess.run(["pkill", "-f", "live_server.py"], check=True)
-        except Exception as e:
-            pass
+    with open("live.log", "w") as f:
+        f.write("")
 
-    signal.signal(signal.SIGHUP, handle_exit)  # Terminal closed
-    signal.signal(signal.SIGINT, handle_exit)  # Ctrl+C
-    signal.signal(signal.SIGTERM, handle_exit)  # Termination signal
+    include = include.split(",") if include else None
+    exclude = exclude.split(",") if exclude else None
+    server_cli.run_live(include=include, exclude=exclude)
 
-    if types == "server":
-        try:
-            include = include.split(",") if include else None
-            exclude = exclude.split(",") if exclude else None
-            server_cli.run_live(log_file, include, exclude)
-        except:
-            handle_exit(None, None)
 
-    if types == "logs":
-        with open(log_file, "a") as f:
-            f.write("")
-        log_cli.tail_f(log_file)
+@forge.command()
+@click.option("-i", "--include", help="Include functions to watch", default=None)
+@click.option("-e", "--exclude", help="Exclude functions to watch", default=None)
+def logs(include, exclude):
+    """
+    Starts a Log Stream for the specified Lambda functions.
 
-    if types == "trigger":
-        trigger_cli.run_trigger()
+    This command shows the logs of the specified Lambda functions in real-time
+    as an alternative to the AWS CloudWatch console.
+    """
+
+    with open("live.log", "w") as f:
+        f.write("")
+
+    include = include.split(",") if include else None
+    exclude = exclude.split(",") if exclude else None
+    launch_forge_logs_tui({"include": include, "exclude": exclude})
 
 
 @forge.command()
@@ -565,7 +575,9 @@ def deploy(stack, all):
     default="diagram.png",
 )
 @click.option("-i", "--include", help="Comma-separated files to watch", default=None)
-@click.option("-e", "--exclude", help="Comma-separated files to not watch", default=None)
+@click.option(
+    "-e", "--exclude", help="Comma-separated files to not watch", default=None
+)
 def diagram(output_file, include, exclude):
     """
     Create a diagram of the project in png format
@@ -577,7 +589,9 @@ def diagram(output_file, include, exclude):
     try:
         printer.start_spinner("Synthesizing CDK")
         with open(os.devnull, "w") as devnull:
-            subprocess.run(["cdk", "synth"], stdout=devnull, stderr=subprocess.STDOUT, check=True)
+            subprocess.run(
+                ["cdk", "synth"], stdout=devnull, stderr=subprocess.STDOUT, check=True
+            )
 
     except Exception as e:
         printer.print(str(e), "red", 1, 1)
@@ -586,7 +600,9 @@ def diagram(output_file, include, exclude):
 
     functions = json.load(open("functions.json", "r"))
     if exclude:
-        functions = [function for function in functions if function["name"] not in exclude]
+        functions = [
+            function for function in functions if function["name"] not in exclude
+        ]
 
     if include:
         functions = [function for function in functions if function["name"] in include]
@@ -619,7 +635,9 @@ def test(test_type):
         subprocess.run(["pytest", "-k", "integration", "."], check=True)
 
     elif test_type == "coverage":
-        subprocess.run(["coverage", "run", "-m", "pytest", "-k", "unit", "."], check=True)
+        subprocess.run(
+            ["coverage", "run", "-m", "pytest", "-k", "unit", "."], check=True
+        )
         subprocess.run(["coverage", "report"], check=True)
 
     elif test_type == "all":
@@ -675,5 +693,29 @@ def output():
     printer.br()
 
 
+@forge.command()
+@click.argument("stack")
+@click.option(
+    "--interval",
+    help="Query interval for the logs",
+    default=1,
+)
+def logs(stack, interval):
+    """
+    Query periodically the logs of the specified stack on AWS CloudWatch
+    """
+    result = subprocess.run(["cdk", "list"], capture_output=True, text=True)
+    stacks = result.stdout.splitlines()
+    printer.show_banner("Logs")
+    printer.br()
+
+    # Check if the specified stack is in the list of available stacks
+    if not any(stack.lower() in s.lower() for s in stacks):
+        printer.print(f"Stack '{stack}' not found in available stacks: {stacks}", "red")
+        exit()
+
+    functions = json.load(open("functions.json", "r"))
+    watch_logs_for_functions(functions=functions, log_file_path="logs.log", stack=stack, interval=interval)
+
 if __name__ == "__main__":
     forge()
